@@ -112,7 +112,7 @@ class Time(str):
 class ResourceKey(str):
     """Constants for key of resource."""
 
-    ID = "id"
+    NAME = "resourceName"
 
 
 class Symbol(str):
@@ -122,6 +122,7 @@ class Symbol(str):
     POINT = "."
     COMMA = ","
     UNDERLINE = "_"
+    BLANK = " "
 
 
 class Version(str):
