@@ -19,15 +19,15 @@
 
 import json
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set, Union
 
 from pydolphinscheduler import configuration
-from pydolphinscheduler.constants import TaskType
+from pydolphinscheduler.constants import Symbol, TaskType
 from pydolphinscheduler.core.resource import Resource
 from pydolphinscheduler.core.resource_plugin import ResourcePlugin
 from pydolphinscheduler.exceptions import PyDSParamException, PyDSTaskNoFoundException
 from pydolphinscheduler.java_gateway import gateway
-from pydolphinscheduler.models import Base, Project, User
+from pydolphinscheduler.models import Base, Project, Tenant, User
 from pydolphinscheduler.utils.date import MAX_DATETIME, conv_from_str, conv_to_schedule
 
 
@@ -87,6 +87,7 @@ class Workflow(Base):
     _KEY_ATTR = {
         "name",
         "project",
+        "tenant",
         "release_state",
         "param",
     }
@@ -95,6 +96,7 @@ class Workflow(Base):
         "name",
         "description",
         "_project",
+        "_tenant",
         "worker_group",
         "warning_type",
         "warning_group_id",
@@ -108,16 +110,19 @@ class Workflow(Base):
         "resource_list",
     }
 
+    _EXPECT_SCHEDULE_CHAR_NUM = 7
+
     def __init__(
         self,
         name: str,
         description: Optional[str] = None,
         schedule: Optional[str] = None,
-        start_time: Optional[str] = None,
-        end_time: Optional[str] = None,
+        start_time: Optional[Union[str, datetime]] = None,
+        end_time: Optional[Union[str, datetime]] = None,
         timezone: Optional[str] = configuration.WORKFLOW_TIME_ZONE,
         user: Optional[str] = configuration.WORKFLOW_USER,
         project: Optional[str] = configuration.WORKFLOW_PROJECT,
+        tenant: Optional[str] = configuration.WORKFLOW_TENANT,
         worker_group: Optional[str] = configuration.WORKFLOW_WORKER_GROUP,
         warning_type: Optional[str] = configuration.WORKFLOW_WARNING_TYPE,
         warning_group_id: Optional[int] = 0,
@@ -131,12 +136,22 @@ class Workflow(Base):
         **kwargs,
     ):
         super().__init__(name, description)
-        self.schedule = schedule
+        self.schedule = schedule.strip() if schedule else schedule
+        if (
+            self.schedule
+            and self.schedule.count(Symbol.BLANK) != self._EXPECT_SCHEDULE_CHAR_NUM - 1
+        ):
+            raise PyDSParamException(
+                "Invlaid parameter schedule, expect crontab char is %d but get %s",
+                self._EXPECT_SCHEDULE_CHAR_NUM,
+                schedule,
+            )
         self._start_time = start_time
         self._end_time = end_time
         self.timezone = timezone
         self._user = user
         self._project = project
+        self._tenant = tenant
         self.worker_group = worker_group
         self.warning_type = warning_type
         if warning_type.strip().upper() not in ("FAILURE", "SUCCESS", "ALL", "NONE"):
@@ -174,6 +189,16 @@ class Workflow(Base):
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
         WorkflowContext.delete()
 
+    @property
+    def tenant(self) -> Tenant:
+        """Get attribute tenant."""
+        return Tenant(self._tenant)
+
+    @tenant.setter
+    def tenant(self, tenant: Tenant) -> None:
+        """Set attribute tenant."""
+        self._tenant = tenant.name
+
     @property
     def project(self) -> Project:
         """Get attribute project."""
@@ -190,7 +215,7 @@ class Workflow(Base):
 
         For now we just get from python models but not from java gateway models, so it may not correct.
         """
-        return User(name=self._user)
+        return User(name=self._user, tenant=self._tenant)
 
     @staticmethod
     def _parse_datetime(val: Any) -> Any:
@@ -424,6 +449,7 @@ class Workflow(Base):
             self.execution_type,
             self.timeout,
             self.worker_group,
+            self._tenant,
             self.release_state,
             # TODO add serialization function
             json.dumps(self.task_relation_json),
