@@ -18,10 +18,10 @@
 # [start workflow_declare]
 """A example workflow for task spark."""
 
-from pydolphinscheduler.core.process_definition import ProcessDefinition
+from pydolphinscheduler.core.workflow import Workflow
 from pydolphinscheduler.tasks.spark import DeployMode, ProgramType, Spark
 
-with ProcessDefinition(name="task_spark_example", tenant="tenant_exists") as pd:
+with Workflow(name="task_spark_example", tenant="tenant_exists") as workflow:
     task = Spark(
         name="task_spark",
         main_class="org.apache.spark.examples.SparkPi",
@@ -29,5 +29,5 @@ with ProcessDefinition(name="task_spark_example", tenant="tenant_exists") as pd:
         program_type=ProgramType.JAVA,
         deploy_mode=DeployMode.LOCAL,
     )
-    pd.run()
+    workflow.run()
 # [end workflow_declare]
